@@ -1,16 +1,17 @@
+from __future__ import absolute_import
 import contextlib
 
 try:
     from typing import Awaitable
 except ImportError:
-    from future.utils import with_metaclass
+    import six
     from typing import Generic, TypeVar
     from abc import ABCMeta, abstractmethod
 
     T_co = TypeVar('T_co', covariant=True)
 
-
-    class _Awaitable(with_metaclass(ABCMeta)):
+    @six.add_metaclass(ABCMeta)
+    class _Awaitable(object):
 
         __slots__ = ()
 
@@ -18,13 +19,14 @@ except ImportError:
         def __await__(self):
             yield
 
-
     class Awaitable(Generic[T_co], _Awaitable):
         __slots__ = ()
 
+
 try:
     from contextlib import suppress
 except ImportError:
+
     @contextlib.contextmanager
     def suppress(*exceptions):
         """
@@ -37,6 +39,7 @@ except ImportError:
         except exc:
             pass
 
+
 try:
     # Either take the native ones
     ConnectionError = ConnectionError
@@ -46,13 +49,14 @@ except NameError:
     class ConnectionError(Exception):
         pass
 
-
     class ConnectionRefusedError(ConnectionError):
         pass
 
+
 try:
     from contextlib import suppress
 except ImportError:
+
     @contextlib.contextmanager
     def suppress(*exceptions):
         excs = exceptions or Exception
@@ -61,4 +65,5 @@ except ImportError:
         except excs:
             pass
 
+
 __all__ = ('ConnectionError', 'ConnectionRefusedError')
